==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QCocoaGLContext_shell.cpp <==
#include <QtCore/QtGlobal>
#if __has_include(<QtGui/qopenglcontext_platform.h>)
#include <QtGui/qopenglcontext_platform.h>
#endif
#include <QtCore/QVariant>
#include <QtGui/QOpenGLContext>
#include <QtGui/qopenglcontext.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/CoreAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if defined(Q_OS_MACOS)



#endif // defined(Q_OS_MACOS)

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QNativeInterface::QCocoaGLContext::nativeContext()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_nativeinterface_QCocoaGLContext_00024Impl_00024ConcreteWrapper_nativeContext_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if defined(Q_OS_MACOS)
        const QNativeInterface::QCocoaGLContext *__qt_this = QtJambiAPI::interfaceFromNativeId<QNativeInterface::QCocoaGLContext>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNativeInterface::QCocoaGLContext::nativeContext()const", __qt_this)
        NSOpenGLContext* __qt_return_value = __qt_this->nativeContext();
        __java_return_value = QtJambiAPI::convertNativeToQNativePointer(__jni_env, __qt_return_value, QNativePointer::Type::Pointer, 1);
#else
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // defined(Q_OS_MACOS)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNativeInterface::QCocoaGLContext::fromNative(NSOpenGLContext*,QOpenGLContext*)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_nativeinterface_QCocoaGLContext_00024Impl_fromNative_1native_1NSOpenGLContext_1ptr_1QOpenGLContext_1ptr__Lio_qt_QNativePointer_2J)
(JNIEnv *__jni_env,
 jclass,
 jobject context0,
 QtJambiNativeID shareContext1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNativeInterface::QCocoaGLContext::fromNative(NSOpenGLContext*,QOpenGLContext*)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if defined(Q_OS_MACOS)
        NSOpenGLContext* __qt_context0 = reinterpret_cast<NSOpenGLContext* >(QtJambiAPI::convertQNativePointerToNative(__jni_env, context0, 1));
        QOpenGLContext* __qt_shareContext1 = QtJambiAPI::objectFromNativeId<QOpenGLContext>(shareContext1);
        QOpenGLContext* __qt_return_value = QNativeInterface::QCocoaGLContext::fromNative(__qt_context0, __qt_shareContext1);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnershipForTopLevelObject(__jni_env, __qt_return_value);
#else
        Q_UNUSED(context0)
        Q_UNUSED(shareContext1)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // defined(Q_OS_MACOS)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QNativeInterface_QCocoaGLContext(){
    using namespace RegistryAPI;

#if defined(Q_OS_MACOS)

    const std::type_info& typeId = registerInterfaceTypeInfo<QNativeInterface::QCocoaGLContext>("QNativeInterface::QCocoaGLContext", "io/qt/gui/nativeinterface/QCocoaGLContext");
    registerNativeInterface<QNativeInterface::QCocoaGLContext>("io/qt/gui/nativeinterface/QCocoaGLContext");
// BEGIN: function table
    registerConstructorInfos(typeId, nullptr, {
    });
// END: function table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QNativeInterface::QCocoaGLContext* _object = dynamic_cast<QNativeInterface::QCocoaGLContext*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QNativeInterface::QCocoaGLContext *object = reinterpret_cast<QNativeInterface::QCocoaGLContext *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QNativeInterface::QCocoaGLContext *object = reinterpret_cast<const QNativeInterface::QCocoaGLContext *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#else //defined(Q_OS_MACOS)

    registerNativeInterface("io/qt/gui/nativeinterface/QCocoaGLContext", {});

#endif //defined(Q_OS_MACOS)

}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QCocoaGLContext_shell.cpp <==
#include <QtCore/QtGlobal>
#if __has_include(<QtGui/qopenglcontext_platform.h>)
#include <QtGui/qopenglcontext_platform.h>
#endif
#include <QtCore/QVariant>
#include <QtGui/QOpenGLContext>
#include <QtGui/qopenglcontext.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/CoreAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if defined(Q_OS_MACOS)



#endif // defined(Q_OS_MACOS)

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QNativeInterface::QCocoaGLContext::nativeContext()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_nativeinterface_QCocoaGLContext_00024Impl_00024ConcreteWrapper_nativeContext_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if defined(Q_OS_MACOS)
        const QNativeInterface::QCocoaGLContext *__qt_this = QtJambiAPI::interfaceFromNativeId<QNativeInterface::QCocoaGLContext>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNativeInterface::QCocoaGLContext::nativeContext()const", __qt_this)
        NSOpenGLContext* __qt_return_value = __qt_this->nativeContext();
        __java_return_value = QtJambiAPI::convertNativeToQNativePointer(__jni_env, __qt_return_value, QNativePointer::Type::Pointer, 1, 1);
#else
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // defined(Q_OS_MACOS)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNativeInterface::QCocoaGLContext::fromNative(NSOpenGLContext*,QOpenGLContext*)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_nativeinterface_QCocoaGLContext_00024Impl_fromNative_1native_1NSOpenGLContext_1ptr_1QOpenGLContext_1ptr__Lio_qt_QNativePointer_2J)
(JNIEnv *__jni_env,
 jclass,
 jobject context0,
 QtJambiNativeID shareContext1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNativeInterface::QCocoaGLContext::fromNative(NSOpenGLContext*,QOpenGLContext*)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if defined(Q_OS_MACOS)
        NSOpenGLContext* __qt_context0 = reinterpret_cast<NSOpenGLContext* >(QtJambiAPI::convertQNativePointerToNative(__jni_env, context0));
        QOpenGLContext* __qt_shareContext1 = QtJambiAPI::objectFromNativeId<QOpenGLContext>(shareContext1);
        QOpenGLContext* __qt_return_value = QNativeInterface::QCocoaGLContext::fromNative(__qt_context0, __qt_shareContext1);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnershipForTopLevelObject(__jni_env, __qt_return_value);
#else
        Q_UNUSED(context0)
        Q_UNUSED(shareContext1)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // defined(Q_OS_MACOS)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QNativeInterface_QCocoaGLContext(){
    using namespace RegistryAPI;

#if defined(Q_OS_MACOS)

    const std::type_info& typeId = registerInterfaceTypeInfo<QNativeInterface::QCocoaGLContext>("QNativeInterface::QCocoaGLContext", "io/qt/gui/nativeinterface/QCocoaGLContext");
    registerNativeInterface<QNativeInterface::QCocoaGLContext>("io/qt/gui/nativeinterface/QCocoaGLContext");
// BEGIN: function table
    registerConstructorInfos(typeId, nullptr, {
    });
// END: function table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QNativeInterface::QCocoaGLContext* _object = dynamic_cast<QNativeInterface::QCocoaGLContext*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QNativeInterface::QCocoaGLContext *object = reinterpret_cast<QNativeInterface::QCocoaGLContext *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QNativeInterface::QCocoaGLContext *object = reinterpret_cast<const QNativeInterface::QCocoaGLContext *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#else //defined(Q_OS_MACOS)

    registerNativeInterface("io/qt/gui/nativeinterface/QCocoaGLContext", {});

#endif //defined(Q_OS_MACOS)

}
